@@ -21,12 +21,12 @@ import os
 import os.path
 
 PACKAGE    = "sabayon"
-VERSION    = "2.12.2"
-LOCALEDIR = "/gnome/head/INSTALL/share/locale"
-DATADIR    = "/gnome/head/INSTALL/share"
-SYSCONFDIR = "/gnome/head/INSTALL/etc"
-LIBEXECDIR = "/gnome/head/INSTALL/libexec"
-SBINDIR    = "/gnome/head/INSTALL/sbin"
+VERSION    = "2.12.3"
+LOCALEDIR = "/opt/gnome2/share/locale"
+DATADIR    = "/opt/gnome2/share"
+SYSCONFDIR = "/opt/gnome2/etc"
+LIBEXECDIR = "/opt/gnome2/libexec"
+SBINDIR    = "/opt/gnome2/sbin"
 
 GLADEDIR    = os.path.join (DATADIR, "sabayon", "glade")
 PROFILESDIR = os.path.join (SYSCONFDIR, "desktop-profiles")
